==> haskell-bzlib-0.5.2.0-69.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-bzlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bzlib
version:              0.5.2.0
visibility:           public
id:                   bzlib-0.5.2.0-4Eu3YLJP56XBuoTKhV6J7V
key:                  bzlib-0.5.2.0-4Eu3YLJP56XBuoTKhV6J7V
license:              BSD-3-Clause
copyright:            (c) 2006-2015 Duncan Coutts
maintainer:           Duncan Coutts <duncan@community.haskell.org>
author:               Duncan Coutts <duncan@community.haskell.org>
synopsis:             Compression and decompression in the bzip2 format
description:
    This package provides a pure interface for compressing and
    decompressing streams of data represented as lazy
    '\''ByteString'\''s. It uses the bz2 C library so it has high
    performance.

    It provides a convenient high level API suitable for most
    tasks and for the few cases where more control is needed it
    provides access to the full bzip2 feature set.

category:             Codec
abi:                  5ec071f47e4733e16f0a664062fe17a0
exposed:              True
exposed-modules:
    Codec.Compression.BZip Codec.Compression.BZip.Internal

hidden-modules:       Codec.Compression.BZip.Stream
import-dirs:          /usr/lib/ghc-9.6.6/site-local/bzlib-0.5.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bzlib-0.5.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bzlib-0.5.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bzlib
hs-libraries:         HSbzlib-0.5.2.0-4Eu3YLJP56XBuoTKhV6J7V
extra-libraries:      bz2
includes:             bzlib.h
depends:              base-4.18.2.1 bytestring-0.11.5.3
haddock-interfaces:   /usr/share/doc/haskell-bzlib/html/bzlib.haddock
haddock-html:         /usr/share/doc/haskell-bzlib/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bzlib-0.5.2.0-70-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-bzlib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 bzlib
version:              0.5.2.0
visibility:           public
id:                   bzlib-0.5.2.0-LJpH7Dvo8FDKkOSAAkXVpm
key:                  bzlib-0.5.2.0-LJpH7Dvo8FDKkOSAAkXVpm
license:              BSD-3-Clause
copyright:            (c) 2006-2015 Duncan Coutts
maintainer:           Duncan Coutts <duncan@community.haskell.org>
author:               Duncan Coutts <duncan@community.haskell.org>
synopsis:             Compression and decompression in the bzip2 format
description:
    This package provides a pure interface for compressing and
    decompressing streams of data represented as lazy
    '\''ByteString'\''s. It uses the bz2 C library so it has high
    performance.

    It provides a convenient high level API suitable for most
    tasks and for the few cases where more control is needed it
    provides access to the full bzip2 feature set.

category:             Codec
abi:                  480c0aad84c4c25a5bb54584cf9f3de7
exposed:              True
exposed-modules:
    Codec.Compression.BZip Codec.Compression.BZip.Internal

hidden-modules:       Codec.Compression.BZip.Stream
import-dirs:          /usr/lib/ghc-9.6.6/site-local/bzlib-0.5.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/bzlib-0.5.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/bzlib-0.5.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bzlib
hs-libraries:         HSbzlib-0.5.2.0-LJpH7Dvo8FDKkOSAAkXVpm
extra-libraries:      bz2
includes:             bzlib.h
depends:              base-4.18.2.1 bytestring-0.11.5.3
haddock-interfaces:   /usr/share/doc/haskell-bzlib/html/bzlib.haddock
haddock-html:         /usr/share/doc/haskell-bzlib/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
